@@ -2,6 +2,7 @@
 """
 import os
 import copy
+import thornpy
 from . import TMPLT_ENV
 from .utilities import read_TO_file, get_cdb_path, get_full_path
 
@@ -23,9 +24,7 @@ class DrillEvent():
     """
 
     _SCALAR_PARAMETERS = [
-        'File_Type',
         'Units',
-        'File_Version',
         'Event_Name',
         'Drive_Type',
         'Measurement_Tool',
@@ -53,8 +52,6 @@ class DrillEvent():
     ]
     
     _DEFAULT_PARAMETER_SCALARS = {
-        'File_Type': 'event',
-        'File_Version': 1.0,
         'Units': 'Imperial',
         'Drive_Type': 'WITH_MOTOR',
         'Measurement_Tool': 'TOS',
@@ -80,7 +77,7 @@ class DrillEvent():
     }
 
     _TABLE_PARAMETERS = [
-        'TOP_DRIVE',
+        'ROTARY_RPM',
         'MOTOR',
         'PUMP_FLOW',
         'WOB',
@@ -90,7 +87,7 @@ class DrillEvent():
     ]
 
     _DEFAULT_PARAMETER_TABLES = {
-        'TOP_DRIVE': ((),(),()),
+        'ROTARY_RPM': ((),(),()),
         'MOTOR': ((0,), (1,), (1,)),
         'PUMP_FLOW': ((),(),()),
         'WOB': ((),(),()),
@@ -144,18 +141,18 @@ class DrillEvent():
         self.parameters['_DYNAMICS'] = zip(*self.parameters['DYNAMICS'])
     
     def add_ramp(self, parameter, start_time, ramp_duration, delta, clear_existing=False):
-        """Adds a ramp to the specified ramp parameter
+        """Adds a ramp to the specified ramp parameter.
         
         Parameters
         ----------
         parameter : str
-            ramp parameter, options are 'TOP_DRIVE', 'WOB', 'PUMP_FLOW', of 'ROP'
+            ramp parameter, options are 'TOP_DRIVE', 'WOB', 'PUMP_FLOW', or 'ROP'
         start_time : float
             Start time of the ramp.
         ramp_duration : float
             Duration of the ramp.
         delta : float
-            Delta of the ramp.
+            Delta of the ramp.  Units should be in **rpm**, **lbf**, **gpm**, or **ft/sec**.
         clear_existing : bool
             If true, existing ramps for the specified parameter will be deleted.
 
@@ -223,7 +220,7 @@ class DrillEvent():
         
         elif filename is not None:
             # If the filename argument is given
-            filepath = os.path.normpath(filename)
+            filepath = thornpy.utilities.convert_path(filename)
         
         else:
             # Raise an error if none of the arguments are provided
@@ -357,6 +354,17 @@ class DrillEvent():
             for block in blocks:
                 # For each block in the TO file, get the sub blocks
                 sub_blocks = [header for header in tiem_orbit_data[block] if isinstance(tiem_orbit_data[block][header], dict)]
+                
+                # This is a bandaid to make this code backward compatible
+                if 'TOP_DRIVE' in sub_blocks:
+                    
+                    # Replace 'TOP_DRIVE' with 'ROTARY_RPM'
+                    for _i in range(len(sub_blocks)):
+                        if sub_blocks[_i] == 'TOP_DRIVE':
+                            sub_blocks[_i] = 'ROTARY_RPM'
+                            break                   
+
+                    tiem_orbit_data[block]['ROTARY_RPM'] = tiem_orbit_data[block].pop('TOP_DRIVE')
 
                 if param.upper()==block and block=='DYNAMICS':
                     # If the parameter is DYNAMICS and so is the current block
