@@ -5,9 +5,6 @@ import unittest
 import os
 import traceback
 from test import *
-os.environ['ADRILL_SHARED_CFG'] = os.path.join('C:\\', 'MSC.Software', 'Adams', '2018', 'adrill', 'adrill.cfg')
-os.environ['ADRILL_USER_CFG'] = os.path.join(os.environ['USERPROFILE'], '.adrill.cfg')
-os.environ['ADAMS_LAUNCH_COMMAND'] = os.path.join('C:\\', 'MSC.Software', 'Adams', '2018', 'common', 'mdi.bat')
     
 from adamspy import adripy #pylint: disable=wrong-import-position
 
@@ -45,6 +42,43 @@ class Test_DrillString(unittest.TestCase):
         
         # Create a DrillTool object representing a top drive
         self.top_drive = adripy.DrillTool(TEST_TOP_DRIVE_FILE)
+    
+    def test_check_references_two_stabs(self):
+        """Tests that `DrillString.check_for_references` returns two when checking for references to a stabilizer file in a string that has two references.
+
+        """
+        # Create a DrillString object
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_EXISTING_HOLE_FILE, TEST_EVENT_FILE)
+
+        # Add tools to the drill string
+        drill_string.add_tool(self.pdc_bit)
+        drill_string.add_tool(self.motor)
+        drill_string.add_tool(self.stabilizer)
+        drill_string.add_tool(self.mwd)
+        drill_string.add_tool(self.upper_stabilizer)
+
+        # Check the number of references to the stabilizer file
+        num_refs = drill_string.check_for_references(TEST_STABILIZER_FILE)
+
+        self.assertEqual(num_refs, 2)
+    
+    def test_check_references_one_stabs(self):
+        """Tests that `DrillString.check_for_references` returns one when checking for references to a stabilizer file in a string that has one reference
+
+        """
+        # Create a DrillString object
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_EXISTING_HOLE_FILE, TEST_EVENT_FILE)
+
+        # Add tools to the drill string
+        drill_string.add_tool(self.pdc_bit)
+        drill_string.add_tool(self.motor)
+        drill_string.add_tool(self.stabilizer)
+        drill_string.add_tool(self.mwd)
+
+        # Check the number of references to the stabilizer file
+        num_refs = drill_string.check_for_references(TEST_STABILIZER_FILE)
+
+        self.assertEqual(num_refs, 1)
         
     def test_add_tool(self):
         """Test the `DrillString.add_tool()` method.
@@ -279,6 +313,21 @@ class Test_DrillString(unittest.TestCase):
 
         self.assertDictEqual(drill_string_from_file.parameters, expected_parameters)
     
+    
+    def test_read_string_from_file_measure_off_on_drillpipe(self):
+        """Tests that the measures are correct after a string is read from a file.
+
+        """
+        string_file = os.path.join(f'<{TEST_DATABASE_NAME}>', 'drill_strings.tbl', TEST_EXISTING_STRING_NAME + '.str')
+        drill_string_from_file = adripy.DrillString.read_from_file(string_file)
+        
+        drill_pipe = drill_string_from_file.get_tool('drillpipe')
+        for tool in drill_string_from_file.tools:
+            if tool['DrillTool'] is drill_pipe:
+                measure = tool['Measure']
+
+        self.assertEqual(measure, 'no')
+
     def test_read_string_from_file_no_dfb(self):
         
         expected_parameters = {
@@ -462,6 +511,35 @@ class Test_DrillString(unittest.TestCase):
         expected_n_joints = 2
 
         self.assertEqual(actual_n_joints, expected_n_joints)
+    
+    def test_read_string_from_file_wrong_case_in_refs(self):
+        """Tests that a string file is read correctly when it has a collar in it.
+        """
+        # Read new parameters into the drill string object from a file
+        drill_string_from_file = adripy.DrillString.read_from_file(TEST_EXISTING_STRING_FILE_WRONG_CASE)
+        
+        expected_parameters = {
+            'Units': 'Imperial',
+            'ModelName': 'test_string_wrong_case',
+            'OutputName': 'test_string_wrong_case',
+            'Gravity': 32.187,
+            'Deviation_Deg': 0.0,
+            'Adams_Results': 'animation',
+            'Adams_Graphics': 'off',
+            'Adams_Requests': 'on',
+            'Distance_from_Bit': [100.0, 300.0, 500.0],
+            'SolverDLL': 'adrill_solver',
+            'Hole_Property_File': '<ExAmPlE_dAtAbAsE>\\holes.tbl\\test_hole.hol',
+            'Contact_Method': 'Subroutine',
+            'Cyl_Drag_Coeff': 1.0,
+            'Hole_Color': 'LtGray',
+            'Event_Property_File': '<ExAmPlE_dAtAbAsE>\\events.tbl\\test_event.evt'
+        }
+        
+        # Remove some keys from the parameters dictionary
+        drill_string_from_file.parameters.pop('_Distance_from_Bit')
+
+        self.assertDictEqual(drill_string_from_file.parameters, expected_parameters) 
 
     def test_read_string_from_file_relative_references(self):
         """Tests that the string is read correctly when the file uses relative references.
@@ -643,6 +721,14 @@ class Test_DrillString(unittest.TestCase):
         actual_length = drill_string.get_bha_length()
 
         self.assertEqual(actual_length, expected_length)
+
+    def test_get_bha_length_wrong_case(self):
+        """Tests that DrillString.get_bha_length() returns the correct length.
+        """
+        expected_length = 502.393
+        actual_length = adripy.get_bha_length(TEST_EXISTING_STRING_FILE_WRONG_CASE)
+
+        self.assertEqual(actual_length, expected_length)
     
     def test_change_tool_name(self):
         """Tests that changing the name of a :class:`DrillTool` object causes the 'Name' and 'Property_File' values in :attr:`DrillString.tools` to change as well.
