@@ -3,17 +3,115 @@
 import unittest
 import os
 import glob
+import shutil
+import re
 
 import dripy
+import thornpy
 
 from test import *
-os.environ['ADRILL_SHARED_CFG'] = os.path.join('C:\\', 'MSC.Software', 'Adams', '2018', 'adrill', 'adrill.cfg')
-os.environ['ADRILL_USER_CFG'] = os.path.join(os.environ['USERPROFILE'], '.adrill.cfg')
-os.environ['ADAMS_LAUNCH_COMMAND'] = os.path.join('C:\\', 'MSC.Software', 'Adams', '2018', 'common', 'mdi.bat')
     
 from adamspy import adripy #pylint: disable=wrong-import-position
 from adamspy.adripy import DrillSim #pylint: disable=wrong-import-position
 
+class Test_ReadResults(unittest.TestCase):
+
+    def setUp(self):
+        # Create a test config file containing the test database
+        adripy.create_cfg_file(TEST_CONFIG_FILENAME, [TEST_DATABASE_PATH, TEST_NEW_DATABASE_PATH])
+
+        # Create the res and msg files
+        for file in glob.glob(os.path.join(TEST_EXISTING_DRILLSIM_DIRECTORY, '*.cached')):        
+            shutil.copyfile(file, file.replace('.cached', ''))           
+
+        self.drill_sim = DrillSim.read_from_directory(TEST_EXISTING_DRILLSIM_DIRECTORY)        
+        if not self.drill_sim.solved:
+            self.drill_sim.run()
+
+    def test_read_shrink_read(self):
+        """Tests that drill_sim results can be read-and-shrunk, then read again.
+
+        """
+        # Read and shrink
+        self.drill_sim.read_results(t_min=80, t_max=99, shrink_results_file=True)
+        old_reqs = [k for k in self.drill_sim.results]
+        
+        new_drill_sim = DrillSim.read_from_directory(TEST_EXISTING_DRILLSIM_DIRECTORY)                
+        new_drill_sim.read_results(t_min=80, t_max=99)
+        
+        new_reqs = [k for k in new_drill_sim.results]
+
+        self.assertEqual(sorted(old_reqs), sorted(new_reqs))            
+
+    def test_read_and_shrink_1(self):    
+        """Tests that `drill_sim.read_results` produces a smaller results file when reqs_to_read is not specified and a time period is specified. 
+        
+        """
+        # Get the size before shrinking
+        original_size = os.stat(os.path.join(self.drill_sim.directory, self.drill_sim.res_filename)).st_size        
+        
+        # Read and shrink
+        self.drill_sim.read_results(t_min=80, t_max=99, shrink_results_file=True)
+        
+        # Get the size after shrinking
+        new_size = os.stat(os.path.join(self.drill_sim.directory, self.drill_sim.res_filename)).st_size
+
+        # Assert that size before shrinking is greater
+        self.assertGreater(original_size, new_size)
+
+    def test_read_and_shrink_2(self):        
+        """Tests that `drill_sim.read_results` produces a smaller results file when reqs_to_read is specified and a time period is not specified.
+
+        """
+        # Get the size before shrinking
+        original_size = os.stat(os.path.join(self.drill_sim.directory, self.drill_sim.res_filename)).st_size        
+        
+        reqs_to_keep = {
+            'top_drive_data': ['True_Torque', 'Surface_Torque']
+        }
+
+        # Read and shrink
+        self.drill_sim.read_results(reqs_to_read=reqs_to_keep, shrink_results_file=True)
+        
+        # Get the size after shrinking
+        new_size = os.stat(os.path.join(self.drill_sim.directory, self.drill_sim.res_filename)).st_size
+
+        # Assert that size before shrinking is greater
+        self.assertGreater(original_size, new_size)
+
+    def test_read_and_shrink_3(self):        
+        """Tests that `drill_sim.read_results` produces a smaller results file when reqs_to_read is specified and a time period is also specified.
+
+        """
+        # Get the size before shrinking
+        original_size = os.stat(os.path.join(self.drill_sim.directory, self.drill_sim.res_filename)).st_size        
+        
+        reqs_to_keep = {
+            'top_drive_data': ['True_Torque', 'Surface_Torque']
+        }
+
+        # Read and shrink
+        self.drill_sim.read_results(reqs_to_read=reqs_to_keep, t_min=80, t_max=99, shrink_results_file=True)
+        
+        # Get the size after shrinking
+        new_size = os.stat(os.path.join(self.drill_sim.directory, self.drill_sim.res_filename)).st_size
+
+        # Assert that size before shrinking is greater
+        self.assertGreater(original_size, new_size)
+
+    def tearDown(self):
+        # Remove the test cfg file if it exists
+        try:
+            os.remove(TEST_CONFIG_FILENAME)
+        except: #pylint: disable=bare-except
+            pass
+
+        os.remove(os.path.join(self.drill_sim.directory, self.drill_sim.res_filename))
+        os.remove(os.path.join(self.drill_sim.directory, self.drill_sim.msg_filename))
+        
+        # Reset the ADRILL_USER_CFG environment variable
+        os.environ['ADRILL_USER_CFG'] = os.path.join(os.environ['USERPROFILE'], '.adrill.cfg')
+
 class Test_DrillSim(unittest.TestCase):
     """Tests related to the DrillSim class
     """
@@ -59,10 +157,63 @@ class Test_DrillSim(unittest.TestCase):
 
         # Create a solver settings object
         self.solver_settings = adripy.DrillSolverSettings(TEST_SOLVER_SETTINGS_NAME)
-    
-    def test_read_from_file(self):
+
         drill_sim = DrillSim.read_from_directory(TEST_EXISTING_DRILLSIM_DIRECTORY)
-        self.assertEqual(drill_sim.analysis_name, TEST_EXISTING_DRILLSIM_ANALYSIS_NAME)        
+        if drill_sim.built is False:
+            drill_sim.build()
+
+    def test_string_file_contents(self):
+        """Checks that the contents of the string file generated by drill_sim.setup() are as expected.
+        
+        """
+        drill_sim = DrillSim(self.drill_string, self.event, self.solver_settings, TEST_WORKING_DIRECTORY, TEST_ANALYSIS_NAME)
+
+        failures = check_file_contents(drill_sim.string_filename, EXPECTED_DRILLSIM_STRING_FILE_TEXT)
+
+        self.assertListEqual(failures, [])
+        
+    def test_drill_pipe_measure_off_object(self):
+        """Tests that measure is turned off on drill pipe in the string file.
+
+        """
+        drill_sim = DrillSim(self.drill_string, self.event, self.solver_settings, TEST_WORKING_DIRECTORY, TEST_ANALYSIS_NAME)
+        measure = drill_sim.string.tools[2]['Measure']
+        self.assertEqual(measure, 'no')
+
+    def test_stabilizer_measure_on_object(self):
+        """Tests that measure is turned off on drill pipe in the string file.
+
+        """
+        drill_sim = DrillSim(self.drill_string, self.event, self.solver_settings, TEST_WORKING_DIRECTORY, TEST_ANALYSIS_NAME)
+        measure = drill_sim.string.tools[1]['Measure']
+        self.assertEqual(measure, 'yes')
+
+    def test_read_from_directory_analysis_name(self):
+        """Tests that a DrillSim that is read from a directory has the correct analysis name.
+
+        """
+        drill_sim = DrillSim.read_from_directory(TEST_EXISTING_DRILLSIM_DIRECTORY)
+        self.assertEqual(drill_sim.analysis_name, TEST_EXISTING_DRILLSIM_ANALYSIS_NAME)   
+
+    def test_read_from_directory_analysis_built(self):
+        """Tests that a DrillSim that is read from a directory that with a simulation that has been built sets the correct value for DrillSim.built.
+        
+        """
+        drill_sim = DrillSim.read_from_directory(TEST_EXISTING_DRILLSIM_DIRECTORY)
+        self.assertTrue(drill_sim.built)   
+
+    def test_read_from_file_then_build(self):
+        """Tests that a DrillSim can be built after being read in from a directory.
+
+        """
+        # Read in the DrillSim
+        drill_sim = DrillSim.read_from_directory(TEST_EXISTING_UNBUILT_DRILLSIM_DIRECTORY)
+
+        # Build the drill_sim
+        drill_sim.build()
+
+        # Assert that the acf file exists
+        self.assertTrue(os.path.exists(drill_sim.acf_filename))
 
     def test_build_evt_contents(self):
         """Tests that the event file created in the DrillSim directory has the correct contents.        
@@ -84,7 +235,7 @@ class Test_DrillSim(unittest.TestCase):
         drill_sim.build()
         adm_file = os.path.join(TEST_WORKING_DIRECTORY, TEST_ANALYSIS_NAME + '.adm')
         n_adm_lines = len(open(adm_file,'r').readlines())
-        expected_n_adm_lines = 12451
+        expected_n_adm_lines = 12457
         self.assertEqual(n_adm_lines, expected_n_adm_lines)
 
     def test_write_tiem_orbit_files_event_filename(self):
@@ -147,7 +298,7 @@ class Test_DrillSim(unittest.TestCase):
         drill_sim = DrillSim(self.drill_string, self.event, self.solver_settings, TEST_WORKING_DIRECTORY, TEST_ANALYSIS_NAME)
         
         hole_filepath = adripy.get_TO_param(drill_sim.string_filename, 'Hole_Property_File')
-        self.assertFalse(os.path.normpath(drill_sim.directory) in os.path.normpath(hole_filepath))
+        self.assertFalse(thornpy.utilities.convert_path(drill_sim.directory) in thornpy.utilities.convert_path(hole_filepath))
 
     def test_relativity_in_string_event_reference(self):
         """Tests that the file references in the string file are relative to drill_sim.directory       
@@ -155,7 +306,7 @@ class Test_DrillSim(unittest.TestCase):
         drill_sim = DrillSim(self.drill_string, self.event, self.solver_settings, TEST_WORKING_DIRECTORY, TEST_ANALYSIS_NAME)
         
         event_filepath = adripy.get_TO_param(drill_sim.string_filename, 'Event_Property_File')
-        self.assertFalse(os.path.normpath(drill_sim.directory) in os.path.normpath(event_filepath))
+        self.assertFalse(thornpy.utilities.convert_path(drill_sim.directory) in thornpy.utilities.convert_path(event_filepath))
 
     def test_relativity_in_string_pdc_reference(self):
         """Tests that the file references in the string file are relative to drill_sim.directory       
@@ -164,7 +315,7 @@ class Test_DrillSim(unittest.TestCase):
         
         _name, pdc_filepath, _so, _gn = adripy.get_tool_name(drill_sim.string_filename, 'pdc_bit', return_full_path=True)
 
-        self.assertFalse(os.path.normpath(drill_sim.directory) in os.path.normpath(pdc_filepath))
+        self.assertFalse(thornpy.utilities.convert_path(drill_sim.directory) in thornpy.utilities.convert_path(pdc_filepath))
 
     def test_input_deck_directory_contents(self):
         """Tests that the input deck (adm, acf, cmd files) are written to the directory
@@ -310,7 +461,11 @@ class Test_DrillSim(unittest.TestCase):
 
         # Remove all the files in the working directory
         for file in glob.glob(os.path.join(TEST_WORKING_DIRECTORY, '*')):
-            os.remove(file)       
+            os.remove(file)    
+
+        # Remove adm and acf in the unbuilt drillsim directory
+        for file in glob.glob(os.path.join(TEST_EXISTING_UNBUILT_DRILLSIM_DIRECTORY, '*.acf')) + glob.glob(os.path.join(TEST_EXISTING_UNBUILT_DRILLSIM_DIRECTORY, '*.adm')):
+            os.remove(file)
             
 if __name__ == '__main__':
     unittest.main()
